@@ -133,7 +133,7 @@ class App(object):
         errorMsgHtml=f"{errorMsg}<pre>{trace}</pre>"
         self.errors.inner_html=errorMsgHtml
         
-    def createSelect(self,text,value,change,a):
+    def createSelect(self,text,value,change,a,**kwargs):
         '''
         create a select control with a label with the given text, the default value
         and a change onChange function having the parent a
@@ -145,7 +145,7 @@ class App(object):
             a(object): the parent component of the Select control
         '''
         selectorLabel=jp.Label(text=text,a=a,classes="form-label label")
-        select=jp.Select(a=a,classes="form-select",value=value,change=change)
+        select=jp.Select(a=a,classes="form-select",value=value,change=change,**kwargs)
         selectorLabel.for_component=select
         return select
     
@@ -218,7 +218,7 @@ class Link:
     a link
     '''
     @staticmethod
-    def create(url,text,tooltip=None):
+    def create(url,text,tooltip=None,target=None):
         '''
         create a link for the given url and text
         
@@ -228,7 +228,8 @@ class Link:
             tooltip(str): an optional tooltip
         '''
         title="" if tooltip is None else f" title='{tooltip}'"
-        link=f"<a href='{url}{title}'>{text}</a>"
+        target="" if target is None else f" target=' {target}'"
+        link=f"<a href='{url}'{title}{target}>{text}</a>"
         return link
 
              
@@ -340,36 +341,60 @@ class Alert(jp.Div):
 class Collapsible(jp.Div):
     """
     Collapsible div
+    see https://getbootstrap.com/docs/4.0/components/collapse/
     """
-    button_classes = 'btn btn-primary'
+    CHEVRON_DOWN = """<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-down" viewBox="0 0 16 16">
+  <path fill-rule="evenodd" d="M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>
+</svg>"""
 
-    def __init__(self, label:str, **kwargs):
+    CHEVRON_RIGHT = """<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-right" viewBox="0 0 16 16">
+  <path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"/>
+</svg>"""
+
+    def __init__(self, label:str, collapsed:bool=False, **kwargs):
         '''
         constructor
         '''
         super().__init__(**kwargs)
-        self.btn = jp.Button(a=self, text=label, classes=self.button_classes)
-        self.body = jp.Div(a=self)
-        self.body.visibility_state = "invisible"
-        self.btn.body=self.body
-        self.body.a = self
-        self.body.classes=''
-        self.on("click", self.toggle_visible)
+        self.label = label
+        self.btnClasses = "btn btn-secondary d-inline-flex align-items-center rounded"
+        self.btn = None
+        self.body = None
+        self.collapsed=collapsed
+        self.collapse(changeState=False)
 
-    @staticmethod
-    def toggle_visible(self, _msg):
-        if self.body.visibility_state == 'visible':
-            self.body.set_class('invisible')
-            self.body.visibility_state = 'invisible'
+    def collapse(self, changeState:bool=True):
+        """
+        change state of Collapsible body
+        """
+        self.delete_components()
+        if self.collapsed:
+            self.btn = jp.Button(a=self,
+                                 inner_html=f"{self.CHEVRON_DOWN}\n{self.label}",
+                                 classes=self.btnClasses,
+                                 click=self.collapse)
+            self.body = jp.Div(a=self, classes="collapse show",)
         else:
-            self.body.set_class('visible')
-            self.body.visibility_state = 'visible'
-            
+            self.btn = jp.Button(a=self,
+                                 inner_html=f"{self.CHEVRON_RIGHT}\n{self.label}",
+                                 classes=self.btnClasses,
+                                 click=self.collapse)
+            self.body = jp.Div(a=self, classes="collapse")
+        if changeState:
+            self.collapsed = not self.collapsed
+
+    def setCollapseState(self, collapsed:bool):
+        """
+        set the collapse state to the given state
+        """
+        self.collapsed = collapsed
+        self.collapse(changeState=False)
+
+
 class DebugOutput(jp.Div):
     """
     shows debug messages
     """
-
     def __init__(self, **kwargs):
         '''
         constructor
@@ -391,7 +416,7 @@ class DebugOutput(jp.Div):
     def addMessage(self, msg:str):
         '''
         add message
-        
+
         Args:
             msg(str): a message to add
         '''
